@@ -22,10 +22,9 @@
 #' 
 #' @keywords internal
 #' @import data.table
-#' @importFrom tools R_user_dir
 earthworm2human_map <- function(evalue_threshold = NULL,
-                                save_dir = tools::R_user_dir("orthogene",
-                                                             which="cache")){  
+                                save_dir = cache_dir()
+                                ){  
     evalue <- NULL;
     requireNamespace("piggyback")
     
